@@ -1,12 +1,12 @@
 /*
- * Copyright (C) 2006 Christian Stigen Larsen, http://csl.sublevel3.org
+ * Copyright 2006-2016 Christian Stigen Larsen
+ * Copyright 2020 Christoph Raitzig
  * Distributed under the GNU General Public License (GPL) v2.
- *
- * Project homepage on http://jp2a.sf.net
- *
- * $Id: options.h 449 2006-09-18 09:12:18Z csl $
  */
 
+#ifndef INC_JP2A_OPTIONS_H
+#define INC_JP2A_OPTIONS_H
+
 // see options.c
 extern int verbose;
 extern int auto_height;
@@ -31,6 +31,7 @@ extern float redweight, greenweight, blueweight;
 extern float RED[256], GREEN[256], BLUE[256], GRAY[256];
 extern const char *fileout;
 extern int usecolors;
+extern int colorDepth;
 extern int termfit;
 extern int term_width;
 extern int term_height;
@@ -38,3 +39,10 @@ extern int term_height;
 #define TERM_FIT_WIDTH 2
 #define TERM_FIT_HEIGHT 3
 #define TERM_FIT_AUTO 4
+
+void print_version();
+void help();
+void precalc_rgb(const float red, const float green, const float blue);
+void parse_options(int argc, char** argv);
+
+#endif
